<?php

namespace app\models;

use Yii;
use yii\base\Model;

/**
 * LoginForm is the model behind the login form.
 *
 * @property-read User|null $user
 *
 */
class RegisterForm extends Model
{
    public $name;
    public $surname;
    public $patronymic;
    public $login;
    public $phone_number;
    public $email;
    public $password;
    public $password_repeat;
    public $rules;

    private $_user = false;


    public function rules()
    {
        return [
            [['name', 'surname', 'login', 'phone_number', 'email', 'password', 'password_repeat', 'rules'], 'required'],

            [['name', 'surname', 'patronymic'], 'match', 'pattern' => '/^[а-яА-ЯеЁ\s]+$/u', 'message' => 'Доступна только кириллица'],

            [['login'], 'match', 'pattern' => '/^[a-zA-Z0-9]+$/u', 'message' => 'Доступна только латиница'],

            [['login', 'phone_number', 'email'], 'unique', 'targetClass' => 'app\models\User', 'message' => 'Уже занято, введите другие значения'],

            ['password', 'string', 'min' => 6],

            ['password_repeat', 'compare', 'compareAttribute' => 'password', 'message' => 'Пароли не совпадают'],


        ];
    }

    public function attributeLabels()
    {
        return [
            'id' => Yii::t('app', 'ID'),
            'name' => Yii::t('app', 'Имя'),
            'surname' => Yii::t('app', 'Фамилия'),
            'patronymic' => Yii::t('app', 'Отчество'),
            'login' => Yii::t('app', 'Логин'),
            'phone_number' => Yii::t('app', 'Номер телефона'),
            'email' => Yii::t('app', 'Адрес электронной почты'),
            'password' => Yii::t('app', 'Пароль'),
            'password_repeat' => Yii::t('app', 'Повторите пароль'),
            'rules' => Yii::t('app', 'Согласие с правилами регистрации'),
            'is_admin' => Yii::t('app', 'Is Admin'),
        ];
    }


    public function register()
    {
        if (!$this->validate()) {
            return null;
        }
        
        $user = new User();

        $user->name = $this->name;
        $user->surname = $this->surname;
        $user->patronymic = $this->patronymic;
        $user->login = $this->login;
        $user->phone_number = $this->phone_number;
        $user->email = $this->email;
        $user->rules = $this->rules;
        $user->password = Yii::$app->security->generatePasswordHash($this->password);

        return $user->save() ? : null;
    }

    /**
     * Finds user by [[username]]
     *
     * @return User|null
     */
}
