<?php

namespace app\models;

use Yii;
use yii\db\ActiveRecord;

/**
 * This is the model class for table "user".
 *
 * @property int $id
 * @property string $name
 * @property string $surname
 * @property string $patronymic
 * @property string $login
 * @property string $phone_number
 * @property string $email
 * @property string $password
 * @property int $rules
 * @property int $is_admin
 *
 * @property Applications[] $applications
 */

class User extends ActiveRecord implements \yii\web\IdentityInterface
{
    public $authKey;
    public $accessToken;

    private static $users = [];

    public static function tableName()
    {
        return 'user';
    }

    public function rules()
    {
        return [
            [['name', 'surname', 'login', 'phone_number', 'email', 'password', 'rules'], 'required'],
            [['name', 'surname', 'patronymic', 'login', 'phone_number', 'email', 'password'], 'string', 'max' => 256],
            [['phone_number'], 'unique'],
            [['login'], 'unique'],
            [['email'], 'unique'],
        ];
    }

    public function attributeLabels()
    {
        return [
            'id' => Yii::t('app', 'ID'),
            'name' => Yii::t('app', 'Name'),
            'surname' => Yii::t('app', 'Surname'),
            'patronymic' => Yii::t('app', 'Patronymic'),
            'login' => Yii::t('app', 'Login'),
            'phone_number' => Yii::t('app', 'Phone Number'),
            'email' => Yii::t('app', 'Email'),
            'password' => Yii::t('app', 'Password'),
            'rules' => Yii::t('app', 'Rules'),
            'is_admin' => Yii::t('app', 'Is Admin'),
        ];
    }

    public function getApplications()
    {
        return $this->hasMany(Applications::class, ['user_id' => 'id']);
    }



    /**
     * {@inheritdoc}
     */
    public static function findIdentity($id)
    {
        return static::findOne($id);
    }

    /**
     * {@inheritdoc}
     */
    public static function findIdentityByAccessToken($token, $type = null)
    {
        return static::findOne(['access_token' => $token]);
    }

    /**
     * Finds user by username
     *
     * @param string $username
     * @return static|null
     */
    public static function findByLogin($login)
    {
        return static::findOne(['login' => $login]);
    }

    /**
     * {@inheritdoc}
     */
    public function getId()
    {
        return $this->id;
    }

    /**
     * {@inheritdoc}
     */
    public function getAuthKey()
    {
        return $this->authKey;
    }

    /**
     * {@inheritdoc}
     */
    public function validateAuthKey($authKey)
    {
        return $this->authKey === $authKey;
    }

    /**
     * Validates password
     *
     * @param string $password password to validate
     * @return bool if password provided is valid for current user
     */
    public function validatePassword($password)
    {
        return Yii::$app->security->validatePassword($password, $this->password);
    }

    public function generatePasswordHash($password)
    {
        return Yii::$app->security->generatePasswordHash($password);
    }
}
